Python Module Index — macholib 1.8 documentation

# Python Module Index

m

| m |
| `macholib` |
| `macholib.dyld` | Emulation of functonality of the dynamic linker
| `macholib.dylib` | Generic dylib path manipulation
| `macholib.framework` | Generic framework path manipulation
| `macholib.mach_o` | Low-level definitions of elements in a Mach-O file
| `macholib.MachO` | Utilities for reading and writing Mach-O headers
| `macholib.MachOGraph` | Graph data structure of Mach-O dependencies
| `macholib.MachOStandalone` | Create standalone application bundles
| `macholib.ptypes` | Serializable types
| `macholib.SymbolTable` | Class to read the symbol table from a Mach-O header